@@ -150,9 +150,9 @@ class OpenSesameIDE(BaseExtension):
         cfg.opensesame_ide_show_tab_bar = show_tab_bar
         self._scetw.tab_bar_visible = show_tab_bar
 
-    def event_ide_new_file(self, source=None):
+    def event_ide_new_file(self, source=None, ext=None):
 
-        self.new_file()
+        self.new_file(ext=ext)
         if source is None:
             return
         self._current_editor().setPlainText(source)
@@ -233,7 +233,7 @@ class OpenSesameIDE(BaseExtension):
     def open_document(self, path):
 
         # First normalize the path and check if there's a custom handler for it
-        path = os.path.abspath(os.path.normcase(path))
+        path = os.path.abspath(os.path.normpath(path))
         ext = os.path.splitext(path)[1].lstrip('.').lower()
         handler = self.extension_manager.provide(
             'open_file_extension_{}'.format(ext)
@@ -258,7 +258,7 @@ class OpenSesameIDE(BaseExtension):
         for editor in self._scetw.widgets():
             if editor.file.path is None:
                 continue
-            if path == os.path.normpath(os.path.normcase(editor.file.path)):
+            if path == os.path.abspath(os.path.normpath(editor.file.path)):
                 editor.parent().parent().setCurrentWidget(editor)
                 editor.setFocus()
                 return
@@ -353,11 +353,11 @@ class OpenSesameIDE(BaseExtension):
         self._add_recent_folder(path)
         self._remember_open_folders()
 
-    def new_file(self):
+    def new_file(self, ext=None):
 
-        editor = self._current_splitter().create_new_document(
-            extension=cfg.opensesame_ide_default_extension
-        )
+        if not ext:
+            ext = cfg.opensesame_ide_default_extension
+        editor = self._current_splitter().create_new_document(extension=ext)
         self.extension_manager.fire(
             u'register_editor',
             editor=editor
@@ -718,9 +718,12 @@ class OpenSesameIDE(BaseExtension):
     def quick_select_folders(self):
 
         haystack = []
-        for path in cfg.opensesame_ide_recent_folders.split(u';'):
-            if not os.path.isdir(path):
-                continue
+        norm_paths = {
+            os.path.abspath(os.path.normpath(path))
+            for path in cfg.opensesame_ide_recent_folders.split(u';')
+            if os.path.isdir(path)
+        }
+        for path in sorted(norm_paths):
             haystack.append((path, path, self._open_folder))
         self.extension_manager.fire(
             u'quick_select',
@@ -861,7 +864,7 @@ class OpenSesameIDE(BaseExtension):
         if not self.main_window.ui.action_onetabmode.isChecked():
             self.main_window.ui.action_onetabmode.trigger()
         self.tabwidget.add = self._patch_tabwidget_add(self.tabwidget.add)
-        self.tabwidget.tabCloseRequested.connect(self._on_tabwidget_close)
+        self.tabwidget.tab_removed.connect(self._on_tabwidget_close)
         self.tabwidget.shortcut_switch_left.setKey(u'')
         self.tabwidget.shortcut_switch_right.setKey(u'')
         # Create a custom menubar
